<?php
/**
 * prakashan functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package prakashan
 */

/**
 * Check the theme requirements on activation
 */
require get_template_directory() . '/inc/requirements.php';

if ( ! function_exists( 'prakashan_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function prakashan_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on prakashan, use a find and replace
	 * to change 'prakashan' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'prakashan', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary', 'prakashan' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See https://developer.wordpress.org/themes/functionality/post-formats/
	 */
	add_theme_support( 'post-formats', array(
		'aside',
		'image',
		'video',
		'quote',
		'link',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'prakashan_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );

	// Set up the WordPress Theme logo feature.
	$defaults = array(
		'width'       => 200,
		'height'      => 50,
		'flex-height' => true,
		'flex-width'  => true,
	);
	add_theme_support( 'custom-logo', $defaults );		
    

}
endif;
add_action( 'after_setup_theme', 'prakashan_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function prakashan_content_width() {

	if ( ! isset( $content_width ) ) $content_width = 1024;

}
add_action( 'after_setup_theme', 'prakashan_content_width', 0 );

/**
 * Enqueue scripts and styles.
 */
function prakashan_scripts() {
	
	// JS Files
	wp_enqueue_script( 'jquery');
	
	wp_enqueue_style( 'prakashan-style', get_stylesheet_uri() );

	wp_enqueue_script( 'prakashan-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true );

	wp_enqueue_script( 'prakashan-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );

	// Add Genericons font, used in the main stylesheet.
	if ( wp_style_is( 'genericons', 'registered' ) )
		wp_enqueue_style( 'genericons' );
	else
		wp_enqueue_style( 'genericons', get_template_directory_uri() . '/fonts/genericons.css', array(), null );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'prakashan_scripts' );

/**
 * Add read more link to excerpt
 */
function prakashan_excerpt_more( $more ) {
    return ' ... ';
}
add_filter( 'excerpt_more', 'prakashan_excerpt_more' );


/**
 * Modify the custom excerpt & add read more link 
 */
function prakashan_excerpt_more_link( $excerpt ){
	
	$excerpt = wp_strip_all_tags($excerpt, true);
	return '<p> '. $excerpt . ' <a class="read-more more-link" href="'.get_the_permalink().'">'. esc_html__('Read more', 'prakashan'). ' &raquo;</a></p>';
}
add_filter( 'the_excerpt', 'prakashan_excerpt_more_link', 21 );


/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Add the theme info page
 */
require get_template_directory() . '/inc/welcome.php';